;****************************************************************************************
;                                                                             
;    Filename:  EA DOG GLCD 128x64 GLCD for PIC18Fxxxx         			          
;	 =================================================  			
;
;	 by Richard.C  England  16 July 2008
;
;
;	Suits only  EA DOG M or L Displays




;	Processor Type
;	==============

	LIST P=18F4620,r=hex,n=80,x=off,st=off
	errorlevel -302

	#include <P18F4620.INC>	



;****************************************************************************************
; 
;	Configuration bits 
;	==================
  

 CONFIG OSC=INTIO67, PWRT=ON, BOREN=OFF, WDT=OFF, MCLRE=OFF, LPT1OSC=OFF, PBADEN=OFF
 CONFIG LVP=OFF, XINST=OFF, DEBUG=OFF


;******************************************************************************
;
;	Variable definitions
;	====================


	cblock  0x000

	d1									; delay routine work files
	d2
	d3				
	GWORK1								; glcd work files
	GWORK2
	GWORK3
	GPAGENUM							; holds the current page number			
	TABWORK								; tables work file

	ENDC


;****************************************************************************************
;
;	Reset vector
;	============

		ORG	0x0000
		nop
bootup	goto	Main					;go to start of main code


;****************************************************************************************
;
;	Start of main program
;	=====================

; initialisation of system, clear RAM , setup i/o ports



Main	movlw	b'01100010'				; set internal osc to 4 mhz
		movwf	OSCCON

	


;	SPI PORT ALLOCATION		PortA,5  Glcd  CS  Chip Select (L)
;							PortC,2	 Glcd  A/0 or RS  Command/Data select
;							PortC,3	 SPI   CLK Output
;		 					PortC,5  SPI   SDO Data Stream Output
;							PortC,4	 SPI   SDI Data Stream Input - loop back - 
;										   - connected to SDO by a 2k2 resistor




	#define GLCD_CSEL   PORTA,5			; Glcd Chip Select 
	#define	GLCD_A0		PORTC,2			; Glcd A0  command/data control



			
ports	clrf	PORTA
		clrf	PORTB
		clrf	PORTC
		clrf	PORTD
		clrf	PORTE

		movlw	b'00001101'				; set portA 0 & 1 as adc input bit 7 rjust
		movwf	ADCON1					; by loading value to adcon1 reg
		movlw	b'00011011'				; set trisa direction is input
		movwf	TRISA					; bit0,1 adc,   bit2,5,6,7 DO,  bit3,4, DI 

		movlw	b'00000000'				; set portB as Outputs
		movwf	TRISB

		movlw	b'00110000'				; set portC as Outputs,  BITS 4 and 5 input for SPI
		movwf	TRISC

		movlw	b'11111111'				; set portD as Input
		movwf	TRISD

		movlw	b'00001111'     		; set portE as Inputs
		movwf	TRISE





; ***************************************************************************************
;
;	GLCD Main Loop
;	==============
;



glcd_main	call	delay500			; little delay to let glcd boot up
			call	delay500

			call	spi_init			; Initialise SPI routine
			call	glcd_init			; Initialise GLCD routine


gloop		call	glcd_bmp			; Displays a Bitmap Image

			call	delay5sec

			call	send_text			; Sends a line of text

			goto 	gloop







; ***************************************************************************************
;
;	SUBROUTINE		Initialise SPI Routine
;   ==========      ======================		



spi_init
			movlw 	0x10 				; SCK is output (Master), SDI is input,
			movwf 	TRISC 				; SDO is output, all others output
			movlw 	0x40			    ; Mode 1,1 SPI, middle of output
			movwf 	SSPSTAT 			; time sampling
			movlw	0x31 				; Mode 1,1 SPI Master Mode, 
			movwf	SSPCON1 			; SSP is on, 1/16 Tosc bit time
			bsf     GLCD_CSEL				; Disable Chip Select Output (high)
			bsf	 	GLCD_A0				; set  to H for Data
	
			return
		



; ***************************************************************************************
;
;	SUBROUTINE		Initialise EA DOG GLCDs 
;   ==========      =======================		



glcd_init 								; GLCD Init sequence as per Dog data sheet	
										; No. Command		Setting

			movlw   b'01000000'			;  2 - Display start line = 0
			call	glcd_command

	   		movlw	b'10100001'			; 8 - ADC Normal mode = 0 
	    	call	glcd_command

        	movlw	b'11000000'			; 15 - COMS normal = 1/65  duty
	    	call	glcd_command

        	movlw	b'10100110'			;  9 - Display  = normal  - inverse
	    	call	glcd_command

       		movlw	b'10100010'			; 11 - 1/65 duty 1/9 bias for 65x132 display  
	    	call	glcd_command		; ( which is a  64X128 unit)

       		movlw	b'00101111'			; 16  - Power control set = B.,R,F all ON
	    	call	glcd_command

			movlw	b'11111000'			; 20-1 - select Booster ratio set
	   		call	glcd_command

			movlw	b'00000000'			; 20-2 - Booster ratio register
	   		call	glcd_command		;        must be preceeded by 20-1

			movlw	b'00100111'			; 17 - VO volt reg set 
			call	glcd_command

			movlw	b'10000001'			; 18-1 - Elect vol control - contrast
			call	glcd_command

			movlw	b'00010110'			; 18-2 - Contrast level dec 22	
			call	glcd_command		;		 must be preceeded by 18-1

			movlw	b'10101100'			; 19-1 - Static Indicator - set off
		    call	glcd_command

			movlw	b'00000000'			; 19-2 - No Indicator
			call	glcd_command		;		 must be preceeded with 19-1
	
			movlw	b'10101111'			; 20 - Display ON
	        call	glcd_command

;			call	glcd_cram			; clear glcd dispaly ram
		
        	return


		


; ***************************************************************************************
;
;	SUBROUTINE		Write a Command to the GLCD
;   ==========      ===========================		


glcd_command 							 
			movwf	d1					; movW to temp file d1
			bcf		GLCD_CSEL				; Enable Chip Select output (low)
			bcf 	GLCD_A0		 		; Enable Command Output (low)			
			nop							; let ports settle
			movff   d1,SSPBUF 			; put command in SSPBUF
glcd_lpc	btfss   SSPSTAT,BF 			; Data transfer complete? (Buffer Full?)
			goto 	glcd_lpc			; if not, check again
			movf 	SSPBUF,W 			; Get Data from SSPBUF  - Throw it away
			bsf 	GLCD_CSEL				; Disable Chip Select Output (high)
			bsf		GLCD_A0				; set back tgo H for Data

			return



; ***************************************************************************************
;
;	SUBROUTINE		Write Data to the GLCD
;   ==========      =======================


glcd_data								 ; Write Data to the GLCD
			movwf	d1					 ; movW to temp file d1
			bcf		GLCD_CSEL				 ; Enable Chip Select output (low)
			bsf 	GLCD_A0		 		 ; Enable Data Output (high)			
			nop							 ; let ports settle
			movff   d1,SSPBUF 			 ; put data in SSPBUF
glcd_lpd    btfss   SSPSTAT,BF 		 	 ; Data transfer complete? (Buffer Full?)
			goto 	glcd_lpd			 ; if not, check again
			movf 	SSPBUF,W 			 ; Get Data from SSPBUF  - Throw it away
			bsf 	GLCD_CSEL		 		 ; Disable Chip Select Output (high)

			return




; ***************************************************************************************
;
;	SUBROUTINE		Delays based on 4meg osc
;   ==========      ========================		





delay1ms	movlw	0xC6				 ; delay 1ms
			movwf	d1
			movlw	0x01
			movwf	d2
dly1ms		decfsz	d1, f
			goto	dly1msa
			decfsz	d2, f
dly1msa		goto	dly1ms
			nop							
			nop
			nop			
		
			return



delay250	movlw	d'250'				 ; delay 250 ms 
			movwf	d1
dly1		 movlw	0xC7
			movwf	d2
			movlw	0x01
			movwf	d3
Delay_0
			decfsz	d2, f
			goto	dly2
			decfsz	d3, f
dly2		 goto	Delay_0
			decfsz	d1	,f
			goto	dly1

			return



delay500	call	delay250			 ; delay 500ms
			call	delay250

			return



delay1sec	call	delay500			 ; delay 1sec
			call	delay500	

			return



delay5sec	call 	delay1sec			 ; delay 5sec
			call 	delay1sec
			call	delay1sec
			call	delay1sec
			call	delay1sec

			return













; ***************************************************************************************
;
;	SUBROUTINE		Display a line of Text
;   ==========      ======================		



glcd_page0data 								; setup table and display text
		
			clrf	GWORK3
gnext_pb1	movlw	high gpage0_data		; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper gpage0_data		; load font1 U address
			movwf	TBLPTRU			
  			movlw	low gpage0_data			; load font1 L address to tbptrL
			movwf	TBLPTRL
			movf	GWORK3,W
			addwf	TBLPTRL

			tblrd	*+            			;read table entry into TABLAT
			movf	TABLAT,w      			;in WREG
			call	glcd_write_character	; get  data and write out
			incf	GWORK3
			MOVLW	.16
			CPFSEQ	GWORK3
			goto	gnext_pb1
	
  
			return



; ***************************************************************************************
;
;	SUBROUTINE		Write Text Strings
;   ==========      ==================		



glcd_write_character					 ; takes a character, looks up the pixel data and sends out
			clrf	PRODL
			clrf	PRODH
			addlw	-.32			  	 ; subtract 32 to get value
			mullw	.8					 ; multipy  value by 8 to get offset value
										 ; result in PRODL AND PRODH
			movlw	.8					 ; preload data byte counter for 7 bits
			movwf	GWORK2
			bcf		STATUS,C			 ; clear carry bit
			movlw	high Font1		 	 ; load font1 H address to tbptrH
			movwf	TBLPTRH
			movf	PRODH,W				 ; add in any prodH offset value
			addwf	TBLPTRH,F
			movlw	upper Font1			 ; load font1 U address
			movwf	TBLPTRU			
  
			movlw	low Font1			 ; load font1 L address to tbptrL
			movwf	TBLPTRL
			movf	PRODL,W				 ; add ProdL with offset value
			addwf	TBLPTRL 
			btfsc	STATUS,C			 ; has add created a carry over
			incf	TBLPTRH,F			 ; yes, so add 1 to tbptrH



gnext_pb	tblrd	*+             		 ;read table entry into TABLAT
			movf	TABLAT,w       		 ;in WREG
			call	glcd_data			 ; send data 
			decfsz	GWORK2
			goto	gnext_pb
	
  
			return


; ***************************************************************************************
;
;	SUBROUTINE		Display Bitmap Image
;   ==========      ====================		


glcd_bmp 								 ; Setup Table for Bitmap	

			clrf	GWORK1
			movlw	b'10110000'			 ; load page value as h B0
			movwf	GPAGENUM
		  	call	glcd_command
			movlw   b'01000000'			 ; 2 - Display start line = 0
			call	glcd_command
			movlw 	b'00000000'			 ; 2 - Display Column L = 0
		    call	glcd_command
	 		movlw 	b'00010000'			 ; 2 - Display Column H = 0
		    call	glcd_command
	
		
gnext_pb12	movlw	high eadogl			 ; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper eadogl		 ; load font1 U address
			movwf	TBLPTRU			
  			movlw	low eadogl			 ; load font1 L address to tbptrL
			movwf	TBLPTRL
			
			call	gbmpget				 ; routine to get data and write out image

			return	


; ***************************************************************************************
;
;	SUBROUTINE		BitMap Table Read Sub   - Write out Bitmap Image
;	==========      ================================================


gbmpget		clrf	GWORK1
			movlw	b'10110000'			 ; load page value as h B0
			movwf	GPAGENUM
		  	call	glcd_command
			movlw   b'01000000'			 ; 2 - Display start line = 0
			call	glcd_command
			movlw 	b'00000000'			 ; 4 - Display Column L = 0
		    call	glcd_command
	 		movlw 	b'00010000'			 ; 4 - Display Column H = 0
		    call	glcd_command
		
gnextrd		tblrd	*+            		 ; read table entry into TABLAT
			movf	TABLAT,w      		 ; in WREG
			call	glcd_data			 ; send line data
			incf	GWORK1
			movlw	.128				 ; have 128 lines been done
			cpfseq	GWORK1		  		 ; if so, inc page no. and next page
			goto	gnextrd		
			clrf	GWORK1
			incf	GPAGENUM			 ; increment to next page
			movf	GPAGENUM,W   	 	 ; 2 - Display page = 0+
		  	call	glcd_command
			movlw   b'01000000'			 ; 2 - Display start line = 0
			call	glcd_command
			movlw 	b'00000000'			 ; 4 - Display Column L = 0
		    call	glcd_command
	 		movlw 	b'00010000'			 ; 4 - Display Column H = 0
		    call	glcd_command
			movlw	0xB8
			cpfseq	GPAGENUM
			goto	gnextrd
			
			return



; ***************************************************************************************
;
;	SUBROUTINE		Write a string of Text to Display and Invert
;	==========      ============================================





send_text	movlw	b'10110000'			; load page value as h B0
			movwf	GPAGENUM

sendplp			movlw   b'01000000'		; 2 - Display start line = 0
			call	glcd_command

			movf	GPAGENUM,W   		; 2 - Display page = 0+
		  	call	glcd_command

			movlw 	b'00000000'			; 2 - Display Column L = 0
		    call	glcd_command

    		movlw 	b'00010000'			; 2 - Display Column H = 0
		    call	glcd_command

			call  	glcd_page0data

			incf	GPAGENUM			; page displayed so inc page number
			movlw	0xB8				; if page number is 8 then all done
			cpfseq	GPAGENUM
			goto	sendplp


			call	delay500
			call	delay500
			call	delay500
			call	delay500
	        movlw	b'10100111'			;  9 - Display  =  inverse
	  	    call	glcd_command
			call	delay500
			call	delay500
			call	delay500
			call	delay500
	        movlw	b'10100110'			;  9 - Display  = normal 
		    call	glcd_command

			return


; ***************************************************************************************
;
;	TEXT STRINGS
;   ===========


  
gpage0_data

    db  "EA DOG M/L GLCDs, 0			; page 0

gpage1_data

	db	"1234567890!$%&*", 0			; page 1

etc_etc

	db	"ABCDEFGHIJKLMNOP", 0			; page 2
    db	"abcdefghijklmnop", 0 			; page 3
	db  "RS Glcd 627-1848", 0			; page 4
	db	"1234567890!$%&*", 0			; page 5
	db	"ABCDEFGHIJKLMNOP", 0			; page 6
    db	"abcdefghijklmnop", 0 			; page 7




; ***************************************************************************************
;
;	FONTS
;   =====

   
Font1

     db 0x00,0x00,0x00,0x00,0x00,0x00,0x00    ; ' '
     db 0x00,0x06,0x5F,0x5F,0x06,0x00,0x00    ; '!'
     db 0x00,0x07,0x07,0x00,0x07,0x07,0x00    ; '"'
     db 0x14,0x7F,0x7F,0x14,0x7F,0x7F,0x14    ; '#'
     db 0x24,0x2E,0x6B,0x6B,0x3A,0x12,0x00    ; '$'
     db 0x46,0x66,0x30,0x18,0x0C,0x66,0x62    ; '%'
     db 0x30,0x7A,0x4F,0x5D,0x37,0x7A,0x48    ; '&'
     db 0x04,0x07,0x03,0x00,0x00,0x00,0x00    ; '''
     db 0x00,0x1C,0x3E,0x63,0x41,0x00,0x00    ; '('
     db 0x00,0x41,0x63,0x3E,0x1C,0x00,0x00    ; ')'
     db 0x08,0x2A,0x3E,0x1C,0x1C,0x3E,0x2A    ; '*'
     db 0x08,0x08,0x3E,0x3E,0x08,0x08,0x00    ; '+'
     db 0x00,0x80,0xE0,0x60,0x00,0x00,0x00    ; ','
     db 0x08,0x08,0x08,0x08,0x08,0x08,0x00    ; '-'
     db 0x00,0x00,0x60,0x60,0x00,0x00,0x00    ; '.'
     db 0x60,0x30,0x18,0x0C,0x06,0x03,0x01    ; '/'
     db 0x3E,0x7F,0x71,0x59,0x4D,0x7F,0x3E    ; '0'
     db 0x40,0x42,0x7F,0x7F,0x40,0x40,0x00    ; '1'
     db 0x62,0x73,0x59,0x49,0x6F,0x66,0x00    ; '2'
     db 0x22,0x63,0x49,0x49,0x7F,0x36,0x00    ; '3'
     db 0x18,0x1C,0x16,0x53,0x7F,0x7F,0x50    ; '4'
     db 0x27,0x67,0x45,0x45,0x7D,0x39,0x00    ; '5'
     db 0x3C,0x7E,0x4B,0x49,0x79,0x30,0x00    ; '6'
     db 0x03,0x03,0x71,0x79,0x0F,0x07,0x00    ; '7'
     db 0x36,0x7F,0x49,0x49,0x7F,0x36,0x00    ; '8'
     db 0x06,0x4F,0x49,0x69,0x3F,0x1E,0x00    ; '9'
     db 0x00,0x00,0x66,0x66,0x00,0x00,0x00    ; ':'
     db 0x00,0x80,0xE6,0x66,0x00,0x00,0x00    ; ';'
     db 0x08,0x1C,0x36,0x63,0x41,0x00,0x00    ; '<'
     db 0x24,0x24,0x24,0x24,0x24,0x24,0x00    ; '='
     db 0x00,0x41,0x63,0x36,0x1C,0x08,0x00    ; '>'
     db 0x02,0x03,0x51,0x59,0x0F,0x06,0x00    ; '?'
     db 0x3E,0x7F,0x41,0x5D,0x5D,0x1F,0x1E    ; '@'
     db 0x7C,0x7E,0x13,0x13,0x7E,0x7C,0x00    ; 'A'
     db 0x41,0x7F,0x7F,0x49,0x49,0x7F,0x36    ; 'B'
     db 0x1C,0x3E,0x63,0x41,0x41,0x63,0x22    ; 'C'
     db 0x41,0x7F,0x7F,0x41,0x63,0x3E,0x1C    ; 'D'
     db 0x41,0x7F,0x7F,0x49,0x5D,0x41,0x63    ; 'E'
     db 0x41,0x7F,0x7F,0x49,0x1D,0x01,0x03    ; 'F'
     db 0x1C,0x3E,0x63,0x41,0x51,0x73,0x72    ; 'G'
     db 0x7F,0x7F,0x08,0x08,0x7F,0x7F,0x00    ; 'H'
     db 0x00,0x41,0x7F,0x7F,0x41,0x00,0x00    ; 'I'
     db 0x30,0x70,0x40,0x41,0x7F,0x3F,0x01    ; 'J'
     db 0x41,0x7F,0x7F,0x08,0x1C,0x77,0x63    ; 'K'
     db 0x41,0x7F,0x7F,0x41,0x40,0x60,0x70    ; 'L'
     db 0x7F,0x7F,0x0E,0x1C,0x0E,0x7F,0x7F    ; 'M'
     db 0x7F,0x7F,0x06,0x0C,0x18,0x7F,0x7F    ; 'N'
     db 0x1C,0x3E,0x63,0x41,0x63,0x3E,0x1C    ; 'O'
     db 0x41,0x7F,0x7F,0x49,0x09,0x0F,0x06    ; 'P'
     db 0x1E,0x3F,0x21,0x71,0x7F,0x5E,0x00    ; 'Q'
     db 0x41,0x7F,0x7F,0x09,0x19,0x7F,0x66    ; 'R'
     db 0x26,0x6F,0x4D,0x59,0x73,0x32,0x00    ; 'S'
     db 0x03,0x41,0x7F,0x7F,0x41,0x03,0x00    ; 'T'
     db 0x7F,0x7F,0x40,0x40,0x7F,0x7F,0x00    ; 'U'
     db 0x1F,0x3F,0x60,0x60,0x3F,0x1F,0x00    ; 'V'
     db 0x7F,0x7F,0x30,0x18,0x30,0x7F,0x7F    ; 'W'
     db 0x43,0x67,0x3C,0x18,0x3C,0x67,0x43    ; 'X'
     db 0x07,0x4F,0x78,0x78,0x4F,0x07,0x00    ; 'Y'
     db 0x47,0x63,0x71,0x59,0x4D,0x67,0x73    ; 'Z'
     db 0x00,0x7F,0x7F,0x41,0x41,0x00,0x00    ; '['
     db 0x01,0x03,0x06,0x0C,0x18,0x30,0x60    ; '\'
     db 0x00,0x41,0x41,0x7F,0x7F,0x00,0x00    ; ']'
     db 0x08,0x0C,0x06,0x03,0x06,0x0C,0x08    ; '^'
     db 0x80,0x80,0x80,0x80,0x80,0x80,0x80    ; '_'
     db 0x00,0x00,0x03,0x07,0x04,0x00,0x00    ; '`'
     db 0x20,0x74,0x54,0x54,0x3C,0x78,0x40    ; 'a'
     db 0x41,0x7F,0x3F,0x48,0x48,0x78,0x30    ; 'b'
     db 0x38,0x7C,0x44,0x44,0x6C,0x28,0x00    ; 'c'
     db 0x30,0x78,0x48,0x49,0x3F,0x7F,0x40    ; 'd'
     db 0x38,0x7C,0x54,0x54,0x5C,0x18,0x00    ; 'e'
     db 0x48,0x7E,0x7F,0x49,0x03,0x02,0x00    ; 'f'
     db 0x38,0xBC,0xA4,0xA4,0xFC,0x78,0x00    ; 'g'
     db 0x41,0x7F,0x7F,0x08,0x04,0x7C,0x78    ; 'h'
     db 0x00,0x44,0x7D,0x7D,0x40,0x00,0x00    ; 'i'
     db 0x60,0xE0,0x80,0x80,0xFD,0x7D,0x00    ; 'j'
     db 0x41,0x7F,0x7F,0x10,0x38,0x6C,0x44    ; 'k'
     db 0x00,0x41,0x7F,0x7F,0x40,0x00,0x00    ; 'l'
     db 0x78,0x7C,0x1C,0x38,0x1C,0x7C,0x78    ; 'm'
     db 0x7C,0x7C,0x04,0x04,0x7C,0x78,0x00    ; 'n'
     db 0x38,0x7C,0x44,0x44,0x7C,0x38,0x00    ; 'o'
     db 0x00,0xFC,0xFC,0xA4,0x24,0x3C,0x18    ; 'p'
     db 0x18,0x3C,0x24,0xA4,0xF8,0xFC,0x84    ; 'q'
     db 0x44,0x7C,0x78,0x4C,0x04,0x1C,0x18    ; 'r'
     db 0x48,0x5C,0x54,0x54,0x74,0x24,0x00    ; 's'
     db 0x00,0x04,0x3E,0x7F,0x44,0x24,0x00    ; 't'
     db 0x3C,0x7C,0x40,0x40,0x3C,0x7C,0x40    ; 'u'
     db 0x1C,0x3C,0x60,0x60,0x3C,0x1C,0x00    ; 'v'
     db 0x3C,0x7C,0x70,0x38,0x70,0x7C,0x3C    ; 'w'
     db 0x44,0x6C,0x38,0x10,0x38,0x6C,0x44    ; 'x'
     db 0x3C,0xBC,0xA0,0xA0,0xFC,0x7C,0x00    ; 'y'
     db 0x4C,0x64,0x74,0x5C,0x4C,0x64,0x00    ; 'z'
     db 0x08,0x08,0x3E,0x77,0x41,0x41,0x00    ; '{'
     db 0x00,0x00,0x00,0x77,0x77,0x00,0x00    ; '|'
     db 0x41,0x41,0x77,0x3E,0x08,0x08,0x00    ; '}'
     db 0x02,0x03,0x01,0x03,0x02,0x03,0x01    ; '~'
     db 0xFF,0x81,0x81,0x81,0x81,0x81,0xFF    ; ''
     db 0x0E,0x9F,0x91,0xB1,0xFB,0x4A,0x00    ; '255 y dieresi e **** the mplab :-)
 
 


;****************************************************************************************
;
;  Full Screen 128x64 converted BitMap Images
;  ==========================================

; MCDog.bmp (128 x 64)


eadogl

	db	0xFF,0x01,0x01,0x01,0x01,0x01,0xFF,0x00,0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x7F
	db	0x40,0x40,0x40,0x40,0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x3E,0x41,0x41,0x41,0x22
	db	0x00,0x01,0x01,0x7F,0x01,0x01,0x00,0x7F,0x09,0x19,0x29,0x46,0x00,0x3E,0x41,0x41
	db	0x41,0x3E,0x00,0x7F,0x04,0x08,0x10,0x7F,0x00,0x41,0x7F,0x41,0x00,0x3E,0x41,0x41
	db	0x41,0x22,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x0F,0x0F,0x0F,0x1F,0xFE,0xFE
	db	0xFC,0xF0,0x00,0x00,0xF0,0xFC,0xFE,0xFE,0x1F,0x0F,0x0F,0x0F,0x0F,0x1F,0xFE,0xFE
	db	0xFC,0xF0,0x00,0x00,0xF0,0xFC,0xFE,0xFE,0x1F,0x0F,0xCF,0xEF,0xEF,0xEF,0xEF,0xE6
	db	0xC0,0x00,0xC0,0xC0,0xC0,0xC0,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFC,0xFC,0xFC,0xFC,0xFC,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7E
	db	0x11,0x11,0x11,0x7E,0x00,0x46,0x49,0x49,0x49,0x31,0x00,0x46,0x49,0x49,0x49,0x31
	db	0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x7F,0x02,0x0C,0x02,0x7F,0x00,0x7F,0x49,0x49
	db	0x49,0x36,0x00,0x7F,0x40,0x40,0x40,0x40,0x07,0x08,0x70,0x08,0x07,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x3F,0x3F,0x3C,0x3C,0x3C,0x3E,0x1F,0x1F
	db	0x0F,0x03,0x00,0x00,0x03,0x0F,0x1F,0x1F,0x3E,0x3C,0x3C,0x3C,0x3C,0x1E,0x1F,0x1F
	db	0x0F,0x03,0x00,0x00,0x03,0x0F,0x1F,0x1F,0x3E,0x3C,0x3C,0x3D,0x3D,0x3F,0x1F,0x1F
	db	0x07,0x00,0x01,0x01,0x01,0x01,0x00,0x3F,0x3F,0x3F,0x38,0x38,0x38,0x38,0x38,0x38
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00
	db	0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x20,0x40,0xC0,0x80,0x00,0x00,0x00,0x00
	db	0x00,0xC0,0x30,0x08,0x80,0x78,0x40,0x20,0x14,0x8A,0xC0,0xA6,0x50,0x28,0x20,0xC4
	db	0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x70,0x88,0x04
	db	0x02,0xE2,0x22,0x02,0x04,0x88,0x70,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10
	db	0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x02,0x06,0x0A,0x0A,0x12,0x24,0x45,0x8A,0x14,0xB8,0x61,0x42,0x84,0x0C
	db	0x1F,0x30,0xE0,0x00,0x00,0x00,0x08,0x06,0x03,0x61,0x30,0x28,0x94,0x4E,0xB5,0x84
	db	0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x01
	db	0x7E,0xFF,0xFE,0x7E,0x01,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x6E,0x31
	db	0x12,0x14,0x18,0x18,0x08,0x08,0x08,0x04,0x06,0x03,0x02,0x01,0x84,0x80,0x44,0x01
	db	0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x43,0x22,0x11,0x08,0x04
	db	0x03,0x00,0x00,0xE0,0x10,0x00,0x00,0x00,0x00,0x00,0x03,0x8C,0x10,0x60,0x80,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x08,0xFC,0x00,0x00,0x08,0x84,0x44,0x24,0x18,0x00,0xD8,0x24,0x24,0x24
	db	0xD8,0x00,0x10,0xA0,0x40,0xA0,0x10,0x00,0xF0,0x28,0x24,0x24,0xC0,0x00,0x60,0x50
	db	0x48,0xFC,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x06
	db	0x0E,0x0A,0x12,0x14,0x14,0x14,0x14,0x12,0x12,0x12,0x11,0x11,0x88,0x48,0x38,0x18
	db	0x18,0x1C,0x34,0x64,0x64,0xC8,0xF8,0x0F,0x00,0x00,0x00,0x00,0x04,0xF8,0x10,0x90
	db	0x88,0x88,0x7F,0x60,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x18,0xEF,0x88,0x10,0x11
	db	0x22,0x44,0x48,0x50,0x90,0xA0,0x20,0x20,0x20,0xA0,0x60,0x00,0x00,0x00,0x00,0x00
	db	0x10,0x10,0xB8,0x90,0x90,0x90,0x8C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x01,0x01,0x01
	db	0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00
	db	0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0D,0x08,0x1E,0x11,0x18
	db	0x08,0x18,0x18,0x14,0x33,0x31,0x2C,0x20,0x30,0x38,0x20,0x20,0x20,0x17,0x1D,0x01
	db	0x00,0x00,0x10,0x2C,0x22,0x33,0x3C,0x20,0x30,0x28,0x20,0x20,0x27,0x1C,0x01,0x03
	db	0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xE0,0x93,0x90,0xE3,0x94,0x94,0xE3,0x00,0x00,0x00,0x00,0x00,0xFE,0x12,0x12,0x12
	db	0x0C,0x00,0x82,0xFE,0x82,0x00,0x7C,0x82,0x82,0x82,0x44,0x00,0x00,0x00,0x00,0x00
	db	0xFE,0x00,0x6C,0x92,0x92,0x92,0x6C,0x00,0xFE,0x12,0x12,0x12,0x02,0x00,0x00,0x00
	db	0x00,0x00,0x0C,0x92,0x92,0x92,0x60,0x00,0xFE,0x12,0x12,0x12,0x0C,0x00,0x82,0xFE
	db	0x82,0x00,0x00,0x00,0x00,0x00,0xFC,0x22,0x22,0x22,0xFC,0x00,0x0C,0x92,0x92,0x92
	db	0x60,0x00,0x0C,0x92,0x92,0x92,0x60,0x00,0xFE,0x92,0x92,0x92,0x92,0x00,0xFE,0x04
	db	0x08,0x04,0xFE,0x00,0xFE,0x92,0x92,0x92,0x6C,0x00,0xFE,0x80,0x80,0x80,0x80,0x00
	db	0xFE,0x92,0x92,0x92,0x92,0x00,0xFE,0x12,0x32,0x52,0x8C,0x00,0x00,0x00,0x00,0x00




; ***************************************************************************************

	END

; ***************************************************************************************
; ***************************************************************************************
 